==> mandrel-23.0.0.0-Final.tar.gz: mandrel-mandrel-23.0.0.0-Final/docs/reference-manual/native-image/guides/guides.md <==
---
layout: ni-docs-landing
toc_group: how-to-guides
link_title: User Guides
permalink: /native-image/guides/
redirect_from: /reference-manual/native-image/guides/
---

# Native Image User Guides

These guides help developers get started with GraalVM Native Image, acquaint them with available features, and describe potential usage scenarios. 
Here you will learn how to:

- [Access Environment Variables](access-environment-variables.md)
- [Add Logging to a Native Executable](add-logging-to-native-executable.md)
- [Build a Native Executable from a JAR File](build-native-executable-from-jar.md)
- [Build and Run Native Executables with JFR](build-and-run-native-executable-with-jfr.md)
- [Build Java Modules into a Native Executable](build-java-module-app-aot.md)
- [Build a Native Shared Library](build-native-shared-library.md)
- [Build a Polyglot Native Executable (Java and JavaScript)](build-polyglot-native-executable.md)
- [Build a Static or Mostly-Static Native Executable](build-static-and-mostly-static-executable.md)
- [Configure Native Image with the Tracing Agent](build-with-reflection.md)
- [Containerise a Native Executable and Run in a Docker Container](containerise-native-executable-with-docker.md)
- [Create a Heap Dump from a Native Executable](create-heap-dump-from-native-executable.md)
- [Debug Native Executables with GDB](debug-native-executables-with-gdb.md)
- [Include Resources in a Native Executable](include-resources.md)
- [Optimize a Native Executable with Profile-Guided Optimizations](optimize-native-executable-with-pgo.md)
- [Use GraalVM Dashboard to Optimize the Size of a Native Executable](use-graalvm-dashboard.md)
- [Use Gradle to Build a Native Executable from a Java Application](https://graalvm.github.io/native-build-tools/latest/gradle-plugin-quickstart.html)
- [Use Maven to Build a Native Executable from a Java Application](https://graalvm.github.io/native-build-tools/latest/maven-plugin-quickstart.html)
- [Use Shared Reachability Metadata with Native Image Gradle Plugin](use-reachability-metadata-repository-gradle.md)
- [Use System Properties in a Native Executable](use-system-properties.md)

## Microservices Frameworks

- <a href="https://docs.spring.io/spring-boot/docs/3.0.0/reference/htmlsingle/#native-image.developing-your-first-application" target="_blank">Build a Native Executable from a Spring Boot 3 Application</a>
- <a href="https://guides.micronaut.io/latest/micronaut-creating-first-graal-app.html" target="_blank">Build a Native Executable from a Micronaut Application</a>
- <a href="https://quarkus.io/guides/building-native-image" target="_blank">Build a Native Executable from a Quarkus Application</a>
- <a href="https://helidon.io/docs/v3/#/mp/guides/graalnative" target="_blank">Build a Native Executable from a Helidon MP Application</a>
- <a href="https://helidon.io/docs/v3/#/se/guides/graalnative" target="_blank">Build a Native Executable from a Helidon SP Application</a>

==> mandrel-23.1.5.0-Final.tar.gz: mandrel-mandrel-23.1.5.0-Final/docs/reference-manual/native-image/guides/guides.md <==
---
layout: ni-docs-landing
toc_group: how-to-guides
link_title: Guides
permalink: /guides/
redirect_from:
    - /native-image/guides/
    - /reference-manual/native-image/guides/
---

# Guides

These guides help developers get started with GraalVM Native Image, acquaint them with available features, and describe potential usage scenarios. 
Here you will learn how to:

- [Access Environment Variables](access-environment-variables.md)
- [Add Logging to a Native Executable](add-logging-to-native-executable.md)
- [Build a Native Executable from a JAR File](build-native-executable-from-jar.md)
- [Build and Run Native Executables with JFR](build-and-run-native-executable-with-jfr.md)
- [Build Java Modules into a Native Executable](build-java-module-app-aot.md)
- [Build a Native Shared Library](build-native-shared-library.md)
- [Build a Polyglot Native Executable (Java and JavaScript)](build-polyglot-native-executable.md)
- [Build a Static or Mostly-Static Native Executable](build-static-and-mostly-static-executable.md)
- [Configure Native Image with the Tracing Agent](build-with-reflection.md)
- [Containerise a Native Executable and Run in a Docker Container](containerise-native-executable-with-docker.md)
- [Create a Heap Dump from a Native Executable](create-heap-dump-from-native-executable.md)
- [Debug Native Executables with GDB](debug-native-executables-with-gdb.md)
- [Include Resources in a Native Executable](include-resources.md)
- [Optimize a Native Executable with Profile-Guided Optimizations](optimize-native-executable-with-pgo.md)
- [Use GraalVM Dashboard to Optimize the Size of a Native Executable](use-graalvm-dashboard.md)
- [Use Gradle to Build a Native Executable from a Java Application](https://graalvm.github.io/native-build-tools/latest/gradle-plugin-quickstart.html)
- [Use Maven to Build a Native Executable from a Java Application](https://graalvm.github.io/native-build-tools/latest/maven-plugin-quickstart.html)
- [Use Shared Reachability Metadata with Native Image Gradle Plugin](use-reachability-metadata-repository-gradle.md)
- [Use System Properties in a Native Executable](use-system-properties.md)

## Microservices Frameworks

- <a href="https://docs.spring.io/spring-boot/docs/3.0.0/reference/htmlsingle/#native-image.developing-your-first-application" target="_blank">Build a Native Executable from a Spring Boot 3 Application</a>
- <a href="https://guides.micronaut.io/latest/micronaut-creating-first-graal-app.html" target="_blank">Build a Native Executable from a Micronaut Application</a>
- <a href="https://quarkus.io/guides/building-native-image" target="_blank">Build a Native Executable from a Quarkus Application</a>
- <a href="https://helidon.io/docs/v3/#/mp/guides/graalnative" target="_blank">Build a Native Executable from a Helidon MP Application</a>
- <a href="https://helidon.io/docs/v3/#/se/guides/graalnative" target="_blank">Build a Native Executable from a Helidon SP Application</a>
